@@ -106,8 +106,6 @@ class ELISALIB_EXPORT ElisaApplication : public QObject
 
 public:
 
-    static ElisaApplication *create(QQmlEngine *engine, QJSEngine *scriptEngine);
-
     explicit ElisaApplication(QObject *parent = nullptr);
 
     ~ElisaApplication() override;
@@ -218,8 +216,6 @@ public Q_SLOTS:
 
 public:
 
-    void setQmlEngine(QQmlEngine *engine);
-
     KColorSchemeManager *getSchemes();
 
 private Q_SLOTS:
