@@ -13,6 +13,10 @@
 
 #include "localFileConfiguration/elisaconfigurationdialog.h"
 
+#if KFDBusAddons_FOUND
+#include <KDBusService>
+#endif
+
 #if KFFileMetaData_FOUND
 #include "embeddedcoverageimageprovider.h"
 #endif
@@ -76,6 +80,9 @@ int main(int argc, char *argv[])
 
     qputenv("QT_LOGGING_RULES", "org.kde.elisa*=true");
 #endif
+#ifdef Q_OS_WIN
+    qputenv("QT_LOGGING_RULES", "org.kde.elisa*=true");
+#endif
     qputenv("QT_GSTREAMER_USE_PLAYBIN_VOLUME", "true");
 
     QApplication app(argc, argv);
@@ -89,7 +96,11 @@ int main(int argc, char *argv[])
 #ifdef Q_OS_ANDROID
     qInfo() << QCoreApplication::arguments();
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 7, 0)
     QJniObject::callStaticMethod<void>("org/kde/elisa/ElisaService", "startMyService", "(Landroid/content/Context;)V", QNativeInterface::QAndroidApplication::context());
+#else
+    QJniObject::callStaticMethod<void>("org/kde/elisa/ElisaService", "startMyService", QNativeInterface::QAndroidApplication::context());
+#endif
 #endif
 
 #if KFCrash_FOUND
@@ -141,6 +152,16 @@ int main(int argc, char *argv[])
     QQmlApplicationEngine engine;
     engine.addImportPath(QStringLiteral("qrc:/imports"));
     QQmlFileSelector selector(&engine);
+    constexpr auto qmlUri = "org.kde.elisa";
+
+#if KFDBusAddons_FOUND
+    const auto *elisaApplication = engine.singletonInstance<ElisaApplication *>(qmlUri, "ElisaApplication");
+
+    KDBusService service(KDBusService::Unique);
+    service.connect(&service, &KDBusService::activateActionRequested, elisaApplication, &ElisaApplication::activateActionRequested);
+    service.connect(&service, &KDBusService::activateRequested, elisaApplication, &ElisaApplication::activateRequested);
+    service.connect(&service, &KDBusService::openRequested, elisaApplication, &ElisaApplication::openRequested);
+#endif
 
     // Allow image:// icon URLs to be loaded as images im QML
     engine.addImageProvider(QStringLiteral("icon"), new KQuickIconProvider);
@@ -164,7 +185,7 @@ int main(int argc, char *argv[])
 
     engine.rootContext()->setContextProperty(QStringLiteral("elisaStartupArguments"), QVariant::fromValue(urls));
 
-    engine.loadFromModule("org.kde.elisa", "ElisaMainWindow");
+    engine.loadFromModule(qmlUri, "ElisaMainWindow");
 
     return app.exec();
 }
